Marker trait for components that are related to each other in an asymmetric one-to-one
relationship. Note that you should not implement this trait directly; derive it instead.
Derives the AsymmetricOneToOne and Component traits for a struct. Struct must be a tuple
struct with a single Entity field. This restriction will be lifted in the future, but for now
I want to get this out there for people to play with!